@@ -12,6 +12,7 @@ mod filesystem;
 mod table;
 
 use blocks::HumanReadable;
+use clap::builder::ValueParser;
 use table::HeaderMode;
 use uucore::display::Quotable;
 use uucore::error::FromIo;
@@ -20,9 +21,10 @@ use uucore::fsext::{read_fs_list, MountInfo};
 use uucore::parse_size::ParseSizeError;
 use uucore::{format_usage, show};
 
-use clap::{crate_version, Arg, ArgMatches, Command};
+use clap::{crate_version, Arg, ArgMatches, Command, ValueSource};
 
 use std::error::Error;
+use std::ffi::OsString;
 use std::fmt;
 use std::path::Path;
 
@@ -171,8 +173,12 @@ impl fmt::Display for OptionsError {
 impl Options {
     /// Convert command-line arguments into [`Options`].
     fn from(matches: &ArgMatches) -> Result<Self, OptionsError> {
-        let include = matches.values_of_lossy(OPT_TYPE);
-        let exclude = matches.values_of_lossy(OPT_EXCLUDE_TYPE);
+        let include: Option<Vec<_>> = matches
+            .get_many::<OsString>(OPT_TYPE)
+            .map(|v| v.map(|s| s.to_string_lossy().to_string()).collect());
+        let exclude: Option<Vec<_>> = matches
+            .get_many::<OsString>(OPT_EXCLUDE_TYPE)
+            .map(|v| v.map(|s| s.to_string_lossy().to_string()).collect());
 
         if let (Some(include), Some(exclude)) = (&include, &exclude) {
             if let Some(types) = Self::get_intersected_types(include, exclude) {
@@ -187,7 +193,10 @@ impl Options {
             block_size: read_block_size(matches).map_err(|e| match e {
                 ParseSizeError::InvalidSuffix(s) => OptionsError::InvalidSuffix(s),
                 ParseSizeError::SizeTooBig(_) => OptionsError::BlockSizeTooLarge(
-                    matches.value_of(OPT_BLOCKSIZE).unwrap().to_string(),
+                    matches
+                        .get_one::<String>(OPT_BLOCKSIZE)
+                        .unwrap()
+                        .to_string(),
                 ),
                 ParseSizeError::ParseFailure(s) => OptionsError::InvalidBlockSize(s),
             })?,
@@ -200,7 +209,7 @@ impl Options {
                     HeaderMode::PosixPortability
                 // contains_id() doesn't work here, it always returns true because OPT_OUTPUT has
                 // default values and hence is always present
-                } else if matches.occurrences_of(OPT_OUTPUT) > 0 {
+                } else if matches.value_source(OPT_OUTPUT) == Some(ValueSource::CommandLine) {
                     HeaderMode::Output
                 } else {
                     HeaderMode::Default
@@ -430,7 +439,7 @@ impl fmt::Display for DfError {
 
 #[uucore::main]
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
-    let matches = uu_app().get_matches_from(args);
+    let matches = uu_app().try_get_matches_from(args)?;
 
     #[cfg(windows)]
     {
@@ -585,7 +594,7 @@ pub fn uu_app<'a>() -> Command<'a> {
             Arg::new(OPT_TYPE)
                 .short('t')
                 .long("type")
-                .allow_invalid_utf8(true)
+                .value_parser(ValueParser::os_string())
                 .takes_value(true)
                 .value_name("TYPE")
                 .multiple_occurrences(true)
@@ -602,7 +611,7 @@ pub fn uu_app<'a>() -> Command<'a> {
             Arg::new(OPT_EXCLUDE_TYPE)
                 .short('x')
                 .long("exclude-type")
-                .allow_invalid_utf8(true)
+                .value_parser(ValueParser::os_string())
                 .takes_value(true)
                 .value_name("TYPE")
                 .use_value_delimiter(true)
