@@ -32,7 +32,9 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
 
     let after_help = get_long_usage();
 
-    let matches = uu_app().after_help(&after_help[..]).get_matches_from(args);
+    let matches = uu_app()
+        .after_help(&after_help[..])
+        .try_get_matches_from(args)?;
 
     let separator = if matches.contains_id(options::ZERO) {
         "\0"
@@ -51,7 +53,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
             let p = Path::new(path);
             match p.parent() {
                 Some(d) => {
-                    if d.components().next() == None {
+                    if d.components().next().is_none() {
                         print!(".");
                     } else {
                         print_verbatim(d).unwrap();
