@@ -271,7 +271,7 @@ fn expand_shortcuts(args: &[String]) -> Vec<String> {
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     let args = args.collect_ignore();
 
-    let matches = uu_app().get_matches_from(expand_shortcuts(&args));
+    let matches = uu_app().try_get_matches_from(expand_shortcuts(&args))?;
 
     expand(&Options::new(&matches)?).map_err_context(|| "failed to write output".to_string())
 }
@@ -296,19 +296,23 @@ pub fn uu_app<'a>() -> Command<'a> {
                 .value_name("N, LIST")
                 .takes_value(true)
                 .multiple_occurrences(true)
-                .help("have tabs N characters apart, not 8 or use comma separated list of explicit tab positions"),
+                .help(
+                    "have tabs N characters apart, not 8 or use comma separated list \
+                    of explicit tab positions",
+                ),
         )
         .arg(
             Arg::new(options::NO_UTF8)
                 .long(options::NO_UTF8)
                 .short('U')
                 .help("interpret input file as 8-bit ASCII rather than UTF-8"),
-        ).arg(
+        )
+        .arg(
             Arg::new(options::FILES)
                 .multiple_occurrences(true)
                 .hide(true)
                 .takes_value(true)
-                .value_hint(clap::ValueHint::FilePath)
+                .value_hint(clap::ValueHint::FilePath),
         )
 }
 
