@@ -43,7 +43,7 @@ use crate::parse_nrofbytes::parse_number_of_bytes;
 use crate::partialreader::*;
 use crate::peekreader::*;
 use crate::prn_char::format_ascii_dump;
-use clap::{crate_version, AppSettings, Arg, ArgMatches, Command};
+use clap::{crate_version, AppSettings, Arg, ArgMatches, Command, ValueSource};
 use uucore::display::Quotable;
 use uucore::error::{UResult, USimpleError};
 use uucore::format_usage;
@@ -124,19 +124,22 @@ struct OdOptions {
 
 impl OdOptions {
     fn new(matches: &ArgMatches, args: &[String]) -> UResult<Self> {
-        let byte_order = match matches.value_of(options::ENDIAN) {
-            None => ByteOrder::Native,
-            Some("little") => ByteOrder::Little,
-            Some("big") => ByteOrder::Big,
-            Some(s) => {
-                return Err(USimpleError::new(
-                    1,
-                    format!("Invalid argument --endian={}", s),
-                ));
+        let byte_order = if let Some(s) = matches.get_one::<String>(options::ENDIAN) {
+            match s.as_str() {
+                "little" => ByteOrder::Little,
+                "big" => ByteOrder::Big,
+                _ => {
+                    return Err(USimpleError::new(
+                        1,
+                        format!("Invalid argument --endian={}", s),
+                    ))
+                }
             }
+        } else {
+            ByteOrder::Native
         };
 
-        let mut skip_bytes = match matches.value_of(options::SKIP_BYTES) {
+        let mut skip_bytes = match matches.get_one::<String>(options::SKIP_BYTES) {
             None => 0,
             Some(s) => match parse_number_of_bytes(s) {
                 Ok(n) => n,
@@ -164,12 +167,10 @@ impl OdOptions {
 
         let formats = parse_format_flags(args).map_err(|e| USimpleError::new(1, e))?;
 
-        let mut line_bytes = match matches.value_of(options::WIDTH) {
+        let mut line_bytes = match matches.get_one::<String>(options::WIDTH) {
             None => 16,
             Some(s) => {
-                if matches.occurrences_of(options::WIDTH) == 0 {
-                    16
-                } else {
+                if matches.value_source(options::WIDTH) == Some(ValueSource::CommandLine) {
                     match parse_number_of_bytes(s) {
                         Ok(n) => usize::try_from(n)
                             .map_err(|_| USimpleError::new(1, format!("‘{}‘ is too large", s)))?,
@@ -180,6 +181,8 @@ impl OdOptions {
                             ))
                         }
                     }
+                } else {
+                    16
                 }
             }
         };
@@ -194,7 +197,7 @@ impl OdOptions {
 
         let output_duplicates = matches.contains_id(options::OUTPUT_DUPLICATES);
 
-        let read_bytes = match matches.value_of(options::READ_BYTES) {
+        let read_bytes = match matches.get_one::<String>(options::READ_BYTES) {
             None => None,
             Some(s) => match parse_number_of_bytes(s) {
                 Ok(n) => Some(n),
@@ -207,7 +210,7 @@ impl OdOptions {
             },
         };
 
-        let radix = match matches.value_of(options::ADDRESS_RADIX) {
+        let radix = match matches.get_one::<String>(options::ADDRESS_RADIX) {
             None => Radix::Octal,
             Some(s) => {
                 let st = s.as_bytes();
@@ -259,9 +262,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
 
     let clap_opts = uu_app();
 
-    let clap_matches = clap_opts
-        .clone() // Clone to reuse clap_opts to print help
-        .get_matches_from(args.clone());
+    let clap_matches = clap_opts.try_get_matches_from(&args)?;
 
     let od_options = OdOptions::new(&clap_matches, &args)?;
 
