@@ -54,10 +54,10 @@ fn read_until<R: Read>(
 
 #[uucore::main]
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
-    let matches = uu_app().get_matches_from(args);
+    let matches = uu_app().try_get_matches_from(args)?;
 
     let serial = matches.contains_id(options::SERIAL);
-    let delimiters = matches.value_of(options::DELIMITER).unwrap();
+    let delimiters = matches.get_one::<String>(options::DELIMITER).unwrap();
     let files = matches
         .get_many::<String>(options::FILE)
         .unwrap()
