@@ -41,7 +41,7 @@ const POSIX_NAME_MAX: usize = 14;
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     let args = args.collect_lossy();
 
-    let matches = uu_app().get_matches_from(args);
+    let matches = uu_app().try_get_matches_from(args)?;
 
     // set working mode
     let is_posix = matches.get_many::<String>(options::POSIX).is_some();
