@@ -9,9 +9,7 @@
 #[macro_use]
 extern crate quick_error;
 
-use chrono::offset::Local;
-use chrono::DateTime;
-use clap::{AppSettings, Arg, ArgMatches, Command};
+use clap::{crate_version, Arg, ArgMatches, Command};
 use itertools::Itertools;
 use quick_error::ResultExt;
 use regex::Regex;
@@ -20,11 +18,12 @@ use std::fs::{metadata, File};
 use std::io::{stdin, stdout, BufRead, BufReader, Lines, Read, Write};
 #[cfg(unix)]
 use std::os::unix::fs::FileTypeExt;
+use time::macros::format_description;
+use time::OffsetDateTime;
 
 use uucore::display::Quotable;
-use uucore::error::{set_exit_code, UResult};
+use uucore::error::UResult;
 
-const VERSION: &str = env!("CARGO_PKG_VERSION");
 const ABOUT: &str =
     "Write content of given file or standard input to standard output with pagination filter";
 const AFTER_HELP: &str =
@@ -62,6 +61,8 @@ const DEFAULT_COLUMN_WIDTH: usize = 72;
 const DEFAULT_COLUMN_WIDTH_WITH_S_OPTION: usize = 512;
 const DEFAULT_COLUMN_SEPARATOR: &char = &TAB;
 const FF: u8 = 0x0C_u8;
+const DATE_TIME_FORMAT: &[time::format_description::FormatItem] =
+    format_description!("[month repr:short] [day] [hour]:[minute] [year]");
 
 mod options {
     pub const HEADER: &str = "header";
@@ -83,7 +84,6 @@ mod options {
     pub const INDENT: &str = "indent";
     pub const JOIN_LINES: &str = "join-lines";
     pub const HELP: &str = "help";
-    pub const VERSION: &str = "version";
     pub const FILES: &str = "files";
 }
 
@@ -194,13 +194,11 @@ quick_error! {
 
 pub fn uu_app<'a>() -> Command<'a> {
     Command::new(uucore::util_name())
-        .version(VERSION)
+        .version(crate_version!())
         .about(ABOUT)
         .after_help(AFTER_HELP)
         .infer_long_args(true)
         .args_override_self(true)
-        .setting(AppSettings::NoAutoHelp)
-        .setting(AppSettings::NoAutoVersion)
         .arg(
             Arg::new(options::PAGES)
                 .long(options::PAGES)
@@ -360,13 +358,7 @@ pub fn uu_app<'a>() -> Command<'a> {
         .arg(
             Arg::new(options::HELP)
                 .long(options::HELP)
-                .help("Show this help message")
-        )
-        .arg(
-            Arg::new(options::VERSION)
-                .short('V')
-                .long(options::VERSION)
-                .help("Show version information")
+                .help("Print help information")
         )
         .arg(
             Arg::new(options::FILES)
@@ -387,21 +379,10 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
         Ok(m) => m,
         Err(e) => {
             e.print()?;
-            set_exit_code(1);
             return Ok(());
         }
     };
 
-    if matches.contains_id(options::VERSION) {
-        println!("{}", command.render_long_version());
-        return Ok(());
-    }
-
-    if matches.contains_id(options::HELP) {
-        command.print_help()?;
-        return Ok(());
-    }
-
     let mut files = matches
         .get_many::<String>(options::FILES)
         .map(|v| v.map(|s| s.as_str()).collect::<Vec<_>>())
@@ -489,7 +470,7 @@ fn parse_usize(matches: &ArgMatches, opt: &str) -> Option<Result<usize, PrError>
         })
     };
     matches
-        .value_of(opt)
+        .get_one::<String>(opt)
         .map(|i| (i.to_string(), format!("-{}", opt)))
         .map(from_parse_error_to_pr_error)
 }
@@ -520,7 +501,8 @@ fn build_options(
     };
 
     let header = matches
-        .value_of(options::HEADER)
+        .get_one::<String>(options::HEADER)
+        .map(|s| s.as_str())
         .unwrap_or(if is_merge_mode || paths[0] == FILE_STDIN {
             ""
         } else {
@@ -533,7 +515,7 @@ fn build_options(
         parse_usize(matches, options::FIRST_LINE_NUMBER).unwrap_or(Ok(default_first_number))?;
 
     let number = matches
-        .value_of(options::NUMBER_LINES)
+        .get_one::<String>(options::NUMBER_LINES)
         .map(|i| {
             let parse_result = i.parse::<usize>();
 
@@ -575,8 +557,10 @@ fn build_options(
     let line_separator = "\n".to_string();
 
     let last_modified_time = if is_merge_mode || paths[0].eq(FILE_STDIN) {
-        let date_time = Local::now();
-        date_time.format("%b %d %H:%M %Y").to_string()
+        // let date_time = Local::now();
+        // date_time.format("%b %d %H:%M %Y").to_string()
+        let date_time = OffsetDateTime::now_local().unwrap();
+        date_time.format(&DATE_TIME_FORMAT).unwrap()
     } else {
         file_last_modified_time(paths.first().unwrap())
     };
@@ -613,7 +597,7 @@ fn build_options(
     };
 
     let invalid_pages_map = |i: String| {
-        let unparsed_value = matches.value_of(options::PAGES).unwrap();
+        let unparsed_value = matches.get_one::<String>(options::PAGES).unwrap();
         i.parse::<usize>().map_err(|_e| {
             PrError::EncounteredErrors(format!(
                 "invalid --pages argument {}",
@@ -623,7 +607,7 @@ fn build_options(
     };
 
     let start_page = match matches
-        .value_of(options::PAGES)
+        .get_one::<String>(options::PAGES)
         .map(|i| {
             let x: Vec<_> = i.split(':').collect();
             x[0].to_string()
@@ -635,7 +619,7 @@ fn build_options(
     };
 
     let end_page = match matches
-        .value_of(options::PAGES)
+        .get_one::<String>(options::PAGES)
         .filter(|i| i.contains(':'))
         .map(|i| {
             let x: Vec<_> = i.split(':').collect();
@@ -685,9 +669,9 @@ fn build_options(
 
     let across_mode = matches.contains_id(options::ACROSS);
 
-    let column_separator = match matches.value_of(options::COLUMN_STRING_SEPARATOR) {
+    let column_separator = match matches.get_one::<String>(options::COLUMN_STRING_SEPARATOR) {
         Some(x) => Some(x),
-        None => matches.value_of(options::COLUMN_CHAR_SEPARATOR),
+        None => matches.get_one::<String>(options::COLUMN_CHAR_SEPARATOR),
     }
     .map(ToString::to_string)
     .unwrap_or_else(|| DEFAULT_COLUMN_SEPARATOR.to_string());
@@ -1218,8 +1202,12 @@ fn file_last_modified_time(path: &str) -> String {
         .map(|i| {
             i.modified()
                 .map(|x| {
-                    let date_time: DateTime<Local> = x.into();
-                    date_time.format("%b %d %H:%M %Y").to_string()
+                    let date_time: OffsetDateTime = x.into();
+                    let offset = OffsetDateTime::now_local().unwrap().offset();
+                    date_time
+                        .to_offset(offset)
+                        .format(&DATE_TIME_FORMAT)
+                        .unwrap()
                 })
                 .unwrap_or_default()
         })
