@@ -14,6 +14,8 @@ use clap::{crate_version, Arg, Command};
 use remove_dir_all::remove_dir_all;
 use std::collections::VecDeque;
 use std::fs;
+use std::fs::File;
+use std::io::ErrorKind;
 use std::io::{stderr, stdin, BufRead, Write};
 use std::ops::BitOr;
 use std::path::{Path, PathBuf};
@@ -27,6 +29,7 @@ enum InteractiveMode {
     Never,
     Once,
     Always,
+    PromptProtected,
 }
 
 struct Options {
@@ -78,7 +81,9 @@ fn get_long_usage() -> String {
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     let long_usage = get_long_usage();
 
-    let matches = uu_app().after_help(&long_usage[..]).get_matches_from(args);
+    let matches = uu_app()
+        .after_help(&long_usage[..])
+        .try_get_matches_from(args)?;
 
     let files: Vec<String> = matches
         .get_many::<String>(ARG_FILES)
@@ -100,7 +105,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
                 } else if matches.contains_id(OPT_PROMPT_MORE) {
                     InteractiveMode::Once
                 } else if matches.contains_id(OPT_INTERACTIVE) {
-                    match matches.value_of(OPT_INTERACTIVE).unwrap() {
+                    match matches.get_one::<String>(OPT_INTERACTIVE).unwrap().as_str() {
                         "never" => InteractiveMode::Never,
                         "once" => InteractiveMode::Once,
                         "always" => InteractiveMode::Always,
@@ -112,7 +117,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
                         }
                     }
                 } else {
-                    InteractiveMode::Never
+                    InteractiveMode::PromptProtected
                 }
             },
             one_fs: matches.contains_id(OPT_ONE_FILE_SYSTEM),
@@ -147,66 +152,74 @@ pub fn uu_app<'a>() -> Command<'a> {
         .infer_long_args(true)
         .arg(
             Arg::new(OPT_FORCE)
-            .short('f')
-            .long(OPT_FORCE)
-            .multiple_occurrences(true)
-            .help("ignore nonexistent files and arguments, never prompt")
+                .short('f')
+                .long(OPT_FORCE)
+                .multiple_occurrences(true)
+                .help("ignore nonexistent files and arguments, never prompt"),
         )
         .arg(
             Arg::new(OPT_PROMPT)
-            .short('i')
-            .help("prompt before every removal")
-        )
-        .arg(
-            Arg::new(OPT_PROMPT_MORE)
-            .short('I')
-            .help("prompt once before removing more than three files, or when removing recursively. Less intrusive than -i, while still giving some protection against most mistakes")
+                .short('i')
+                .help("prompt before every removal"),
         )
+        .arg(Arg::new(OPT_PROMPT_MORE).short('I').help(
+            "prompt once before removing more than three files, or when removing recursively. \
+            Less intrusive than -i, while still giving some protection against most mistakes",
+        ))
         .arg(
             Arg::new(OPT_INTERACTIVE)
-            .long(OPT_INTERACTIVE)
-            .help("prompt according to WHEN: never, once (-I), or always (-i). Without WHEN, prompts always")
-            .value_name("WHEN")
-            .takes_value(true)
+                .long(OPT_INTERACTIVE)
+                .help(
+                    "prompt according to WHEN: never, once (-I), or always (-i). Without WHEN, \
+                    prompts always",
+                )
+                .value_name("WHEN")
+                .takes_value(true),
         )
         .arg(
             Arg::new(OPT_ONE_FILE_SYSTEM)
-            .long(OPT_ONE_FILE_SYSTEM)
-            .help("when removing a hierarchy recursively, skip any directory that is on a file system different from that of the corresponding command line argument (NOT IMPLEMENTED)")
+                .long(OPT_ONE_FILE_SYSTEM)
+                .help(
+                    "when removing a hierarchy recursively, skip any directory that is on a file \
+                    system different from that of the corresponding command line argument (NOT \
+                    IMPLEMENTED)",
+                ),
         )
         .arg(
             Arg::new(OPT_NO_PRESERVE_ROOT)
-            .long(OPT_NO_PRESERVE_ROOT)
-            .help("do not treat '/' specially")
+                .long(OPT_NO_PRESERVE_ROOT)
+                .help("do not treat '/' specially"),
         )
         .arg(
             Arg::new(OPT_PRESERVE_ROOT)
-            .long(OPT_PRESERVE_ROOT)
-            .help("do not remove '/' (default)")
+                .long(OPT_PRESERVE_ROOT)
+                .help("do not remove '/' (default)"),
         )
         .arg(
-            Arg::new(OPT_RECURSIVE).short('r')
-            .multiple_occurrences(true)
-            .long(OPT_RECURSIVE)
-            .help("remove directories and their contents recursively")
+            Arg::new(OPT_RECURSIVE)
+                .short('r')
+                .multiple_occurrences(true)
+                .long(OPT_RECURSIVE)
+                .help("remove directories and their contents recursively"),
         )
         .arg(
             // To mimic GNU's behavior we also want the '-R' flag. However, using clap's
             // alias method 'visible_alias("R")' would result in a long '--R' flag.
-            Arg::new(OPT_RECURSIVE_R).short('R')
-            .help("Equivalent to -r")
+            Arg::new(OPT_RECURSIVE_R)
+                .short('R')
+                .help("Equivalent to -r"),
         )
         .arg(
             Arg::new(OPT_DIR)
-            .short('d')
-            .long(OPT_DIR)
-            .help("remove empty directories")
+                .short('d')
+                .long(OPT_DIR)
+                .help("remove empty directories"),
         )
         .arg(
             Arg::new(OPT_VERBOSE)
-            .short('v')
-            .long(OPT_VERBOSE)
-            .help("explain what is being done")
+                .short('v')
+                .long(OPT_VERBOSE)
+                .help("explain what is being done"),
         )
         // From the GNU source code:
         // This is solely for testing.
@@ -218,16 +231,16 @@ pub fn uu_app<'a>() -> Command<'a> {
         // hyphens. Therefore it supports 3 leading hyphens.
         .arg(
             Arg::new(PRESUME_INPUT_TTY)
-            .long(PRESUME_INPUT_TTY)
-            .alias(PRESUME_INPUT_TTY)
-            .hide(true)
+                .long(PRESUME_INPUT_TTY)
+                .alias(PRESUME_INPUT_TTY)
+                .hide(true),
         )
         .arg(
             Arg::new(ARG_FILES)
-            .multiple_occurrences(true)
-            .takes_value(true)
-            .min_values(1)
-            .value_hint(clap::ValueHint::AnyPath)
+                .multiple_occurrences(true)
+                .takes_value(true)
+                .min_values(1)
+                .value_hint(clap::ValueHint::AnyPath),
         )
 }
 
@@ -290,13 +303,36 @@ fn handle_dir(path: &Path, options: &Options) -> bool {
             }
         } else {
             let mut dirs: VecDeque<DirEntry> = VecDeque::new();
+            // The Paths to not descend into. We need to this because WalkDir doesn't have a way, afaik, to not descend into a directory
+            // So we have to just ignore paths as they come up if they start with a path we aren't descending into
+            let mut not_descended: Vec<PathBuf> = Vec::new();
 
-            for entry in WalkDir::new(path) {
+            'outer: for entry in WalkDir::new(path) {
                 match entry {
                     Ok(entry) => {
+                        if options.interactive == InteractiveMode::Always {
+                            for not_descend in &not_descended {
+                                if entry.path().starts_with(not_descend) {
+                                    // We don't need to continue the rest of code in this loop if we are in a directory we don't want to descend into
+                                    continue 'outer;
+                                }
+                            }
+                        }
                         let file_type = entry.file_type();
                         if file_type.is_dir() {
-                            dirs.push_back(entry);
+                            // If we are in Interactive Mode Always and the directory isn't empty we ask if we should descend else we push this directory onto dirs vector
+                            if options.interactive == InteractiveMode::Always
+                                && fs::read_dir(entry.path()).unwrap().count() != 0
+                            {
+                                // If we don't descend we push this directory onto our not_descended vector else we push this directory onto dirs vector
+                                if prompt_descend(entry.path()) {
+                                    dirs.push_back(entry);
+                                } else {
+                                    not_descended.push(entry.path().to_path_buf());
+                                }
+                            } else {
+                                dirs.push_back(entry);
+                            }
                         } else {
                             had_err = remove_file(entry.path(), options).bitor(had_err);
                         }
@@ -384,7 +420,7 @@ fn remove_file(path: &Path, options: &Options) -> bool {
     } else {
         true
     };
-    if response {
+    if response && prompt_write_protected(path, false, options) {
         match fs::remove_file(path) {
             Ok(_) => {
                 if options.verbose {
@@ -406,6 +442,38 @@ fn remove_file(path: &Path, options: &Options) -> bool {
     false
 }
 
+fn prompt_write_protected(path: &Path, is_dir: bool, options: &Options) -> bool {
+    if options.interactive == InteractiveMode::Never {
+        return true;
+    }
+    match File::open(path) {
+        Ok(_) => true,
+        Err(err) => {
+            if err.kind() == ErrorKind::PermissionDenied {
+                if is_dir {
+                    prompt(&(format!("rm: remove write-protected directory {}? ", path.quote())))
+                } else {
+                    if fs::metadata(path).unwrap().len() == 0 {
+                        return prompt(
+                            &(format!(
+                                "rm: remove write-protected regular empty file {}? ",
+                                path.quote()
+                            )),
+                        );
+                    }
+                    prompt(&(format!("rm: remove write-protected regular file {}? ", path.quote())))
+                }
+            } else {
+                true
+            }
+        }
+    }
+}
+
+fn prompt_descend(path: &Path) -> bool {
+    prompt(&(format!("rm: descend into directory {}? ", path.quote())))
+}
+
 fn prompt_file(path: &Path, is_dir: bool) -> bool {
     if is_dir {
         prompt(&(format!("rm: remove directory {}? ", path.quote())))
