@@ -11,6 +11,7 @@ use std::ffi::OsString;
 use std::fs::remove_file;
 use std::path::Path;
 
+use clap::builder::ValueParser;
 use clap::{crate_version, Arg, Command};
 
 use uucore::display::Quotable;
@@ -21,7 +22,7 @@ static OPT_PATH: &str = "FILE";
 
 #[uucore::main]
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
-    let matches = uu_app().get_matches_from(args);
+    let matches = uu_app().try_get_matches_from(args)?;
 
     let path: &Path = matches.get_one::<OsString>(OPT_PATH).unwrap().as_ref();
 
@@ -37,7 +38,7 @@ pub fn uu_app<'a>() -> Command<'a> {
             Arg::new(OPT_PATH)
                 .required(true)
                 .hide(true)
-                .allow_invalid_utf8(true)
+                .value_parser(ValueParser::os_string())
                 .value_hint(clap::ValueHint::AnyPath),
         )
 }
