@@ -1,4 +1,4 @@
-// spell-checker:ignore (flags) reflink (fs) tmpfs (linux) rlimit Rlim NOFILE clob btrfs ROOTDIR USERDIR
+// spell-checker:ignore (flags) reflink (fs) tmpfs (linux) rlimit Rlim NOFILE clob btrfs ROOTDIR USERDIR procfs
 
 use crate::common::util::*;
 #[cfg(not(windows))]
@@ -7,8 +7,6 @@ use std::fs::set_permissions;
 #[cfg(not(windows))]
 use std::os::unix::fs;
 
-#[cfg(unix)]
-use std::os::unix::fs::symlink as symlink_file;
 #[cfg(all(unix, not(target_os = "freebsd")))]
 use std::os::unix::fs::MetadataExt;
 #[cfg(all(unix, not(target_os = "freebsd")))]
@@ -50,6 +48,27 @@ static TEST_MOUNT_OTHER_FILESYSTEM_FILE: &str = "mount/DO_NOT_copy_me.txt";
 #[cfg(unix)]
 static TEST_NONEXISTENT_FILE: &str = "nonexistent_file.txt";
 
+/// Assert that mode, ownership, and permissions of two metadata objects match.
+#[cfg(not(windows))]
+macro_rules! assert_metadata_eq {
+    ($m1:expr, $m2:expr) => {{
+        assert_eq!($m1.mode(), $m2.mode(), "mode is different");
+        assert_eq!($m1.uid(), $m2.uid(), "uid is different");
+        assert_eq!($m1.atime(), $m2.atime(), "atime is different");
+        assert_eq!(
+            $m1.atime_nsec(),
+            $m2.atime_nsec(),
+            "atime_nsec is different"
+        );
+        assert_eq!($m1.mtime(), $m2.mtime(), "mtime is different");
+        assert_eq!(
+            $m1.mtime_nsec(),
+            $m2.mtime_nsec(),
+            "mtime_nsec is different"
+        );
+    }};
+}
+
 #[test]
 fn test_cp_cp() {
     let (at, mut ucmd) = at_and_ucmd!();
@@ -73,7 +92,7 @@ fn test_cp_existing_target() {
     assert_eq!(at.read(TEST_EXISTING_FILE), "Hello, World!\n");
 
     // No backup should have been created
-    assert!(!at.file_exists(&*format!("{}~", TEST_EXISTING_FILE)));
+    assert!(!at.file_exists(&format!("{}~", TEST_EXISTING_FILE)));
 }
 
 #[test]
@@ -204,6 +223,8 @@ fn test_cp_arg_interactive() {
         .arg("-i")
         .pipe_in("N\n")
         .succeeds()
+        .no_stdout()
+        .stderr_contains(format!("overwrite '{}'?", TEST_HOW_ARE_YOU_SOURCE))
         .stderr_contains("Not overwriting");
 }
 
@@ -344,7 +365,7 @@ fn test_cp_arg_backup() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -360,7 +381,7 @@ fn test_cp_arg_backup_with_other_args() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -376,7 +397,7 @@ fn test_cp_arg_backup_arg_first() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -394,7 +415,7 @@ fn test_cp_arg_suffix() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}.bak", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}.bak", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -412,7 +433,7 @@ fn test_cp_arg_suffix_hyphen_value() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}-v", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}-v", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -431,7 +452,7 @@ fn test_cp_custom_backup_suffix_via_env() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}{}", TEST_HOW_ARE_YOU_SOURCE, suffix)),
+        at.read(&format!("{}{}", TEST_HOW_ARE_YOU_SOURCE, suffix)),
         "How are you?\n"
     );
 }
@@ -448,7 +469,7 @@ fn test_cp_backup_numbered_with_t() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -465,7 +486,7 @@ fn test_cp_backup_numbered() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -482,7 +503,7 @@ fn test_cp_backup_existing() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -499,7 +520,7 @@ fn test_cp_backup_nil() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -507,7 +528,7 @@ fn test_cp_backup_nil() {
 #[test]
 fn test_cp_numbered_if_existing_backup_existing() {
     let (at, mut ucmd) = at_and_ucmd!();
-    let existing_backup = &*format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE);
+    let existing_backup = &format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE);
     at.touch(existing_backup);
 
     ucmd.arg("--backup=existing")
@@ -519,7 +540,7 @@ fn test_cp_numbered_if_existing_backup_existing() {
     assert!(at.file_exists(TEST_HOW_ARE_YOU_SOURCE));
     assert!(at.file_exists(existing_backup));
     assert_eq!(
-        at.read(&*format!("{}.~2~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}.~2~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -527,7 +548,7 @@ fn test_cp_numbered_if_existing_backup_existing() {
 #[test]
 fn test_cp_numbered_if_existing_backup_nil() {
     let (at, mut ucmd) = at_and_ucmd!();
-    let existing_backup = &*format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE);
+    let existing_backup = &format!("{}.~1~", TEST_HOW_ARE_YOU_SOURCE);
 
     at.touch(existing_backup);
     ucmd.arg("--backup=nil")
@@ -539,7 +560,7 @@ fn test_cp_numbered_if_existing_backup_nil() {
     assert!(at.file_exists(TEST_HOW_ARE_YOU_SOURCE));
     assert!(at.file_exists(existing_backup));
     assert_eq!(
-        at.read(&*format!("{}.~2~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}.~2~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -556,7 +577,7 @@ fn test_cp_backup_simple() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -591,7 +612,7 @@ fn test_cp_backup_never() {
 
     assert_eq!(at.read(TEST_HOW_ARE_YOU_SOURCE), "Hello, World!\n");
     assert_eq!(
-        at.read(&*format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
+        at.read(&format!("{}~", TEST_HOW_ARE_YOU_SOURCE)),
         "How are you?\n"
     );
 }
@@ -1334,6 +1355,24 @@ fn test_cp_reflink_auto() {
     assert_eq!(at.read(TEST_EXISTING_FILE), "Hello, World!\n");
 }
 
+#[test]
+#[cfg(any(target_os = "linux", target_os = "android", target_os = "macos"))]
+fn test_cp_reflink_none() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    let result = ucmd
+        .arg("--reflink")
+        .arg(TEST_HELLO_WORLD_SOURCE)
+        .arg(TEST_EXISTING_FILE)
+        .run();
+
+    if result.succeeded() {
+        // Check the content of the destination file
+        assert_eq!(at.read(TEST_EXISTING_FILE), "Hello, World!\n");
+    } else {
+        // Older Linux versions do not support cloning.
+    }
+}
+
 #[test]
 #[cfg(any(target_os = "linux", target_os = "android", target_os = "macos"))]
 fn test_cp_reflink_never() {
@@ -1356,7 +1395,7 @@ fn test_cp_reflink_bad() {
         .arg(TEST_HELLO_WORLD_SOURCE)
         .arg(TEST_EXISTING_FILE)
         .fails()
-        .stderr_contains("invalid argument");
+        .stderr_contains("error: \"bad\" isn't a valid value for '--reflink[=<WHEN>...]'");
 }
 
 #[test]
@@ -1379,12 +1418,28 @@ fn test_cp_reflink_insufficient_permission() {
 #[cfg(any(target_os = "linux", target_os = "android"))]
 #[test]
 fn test_closes_file_descriptors() {
+    use procfs::process::Process;
+    let me = Process::myself().unwrap();
+
+    // The test suite runs in parallel, we have pipe, sockets
+    // opened by other tests.
+    // So, we take in account the various fd to increase the limit
+    let number_file_already_opened: u64 = me.fd_count().unwrap().try_into().unwrap();
+    let limit_fd: u64 = number_file_already_opened + 9;
+
+    // For debugging purposes:
+    #[cfg(not(target_os = "android"))]
+    for f in me.fd().unwrap() {
+        let fd = f.unwrap();
+        println!("{:?} {:?}", fd, fd.mode());
+    }
+
     new_ucmd!()
         .arg("-r")
         .arg("--reflink=auto")
         .arg("dir_with_10_files/")
         .arg("dir_with_10_files_new/")
-        .with_limit(Resource::NOFILE, 9, 9)
+        .with_limit(Resource::NOFILE, limit_fd, limit_fd)
         .succeeds();
 }
 
@@ -1666,7 +1721,7 @@ fn test_canonicalize_symlink() {
     let (at, mut ucmd) = at_and_ucmd!();
     at.mkdir("dir");
     at.touch("dir/file");
-    symlink_file("../dir/file", at.plus("dir/file-ln")).unwrap();
+    at.relative_symlink_file("../dir/file", "dir/file-ln");
     ucmd.arg("dir/file-ln")
         .arg(".")
         .succeeds()
@@ -1753,20 +1808,7 @@ fn test_copy_through_dangling_symlink_no_dereference_permissions() {
     {
         let metadata1 = at.symlink_metadata("dangle");
         let metadata2 = at.symlink_metadata("d2");
-        assert_eq!(metadata1.mode(), metadata2.mode(), "mode is different");
-        assert_eq!(metadata1.uid(), metadata2.uid(), "uid is different");
-        assert_eq!(metadata1.atime(), metadata2.atime(), "atime is different");
-        assert_eq!(
-            metadata1.atime_nsec(),
-            metadata2.atime_nsec(),
-            "atime_nsec is different"
-        );
-        assert_eq!(metadata1.mtime(), metadata2.mtime(), "mtime is different");
-        assert_eq!(
-            metadata1.mtime_nsec(),
-            metadata2.mtime_nsec(),
-            "mtime_nsec is different"
-        );
+        assert_metadata_eq!(metadata1, metadata2);
     }
 }
 
@@ -1995,3 +2037,174 @@ fn test_cp_parents_2_link() {
     assert!(at.dir_exists("d/a/link") && !at.symlink_exists("d/a/link"));
     assert!(at.file_exists("d/a/link/c"));
 }
+
+#[test]
+fn test_cp_copy_symlink_contents_recursive() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.mkdir("src-dir");
+    at.mkdir("dest-dir");
+    at.touch("f");
+    at.write("f", "f");
+    at.relative_symlink_file("f", "slink");
+    at.relative_symlink_file("no-file", &path_concat!("src-dir", "slink"));
+    ucmd.args(&["-H", "-R", "slink", "src-dir", "dest-dir"])
+        .succeeds();
+    assert!(at.dir_exists("src-dir"));
+    assert!(at.dir_exists("dest-dir"));
+    assert!(at.dir_exists(&path_concat!("dest-dir", "src-dir")));
+    let regular_file = path_concat!("dest-dir", "slink");
+    assert!(!at.symlink_exists(&regular_file) && at.file_exists(&regular_file));
+    assert_eq!(at.read(&regular_file), "f");
+}
+
+#[test]
+fn test_cp_mode_symlink() {
+    for from in ["file", "slink", "slink2"] {
+        let (at, mut ucmd) = at_and_ucmd!();
+        at.touch("file");
+        at.write("file", "f");
+        at.relative_symlink_file("file", "slink");
+        at.relative_symlink_file("slink", "slink2");
+        ucmd.args(&["-s", "-L", from, "z"]).succeeds();
+        assert!(at.symlink_exists("z"));
+        assert_eq!(at.read_symlink("z"), from);
+    }
+}
+
+// Android doesn't allow creating hard links
+#[cfg(not(target_os = "android"))]
+#[test]
+fn test_cp_mode_hardlink() {
+    for from in ["file", "slink", "slink2"] {
+        let (at, mut ucmd) = at_and_ucmd!();
+        at.touch("file");
+        at.write("file", "f");
+        at.relative_symlink_file("file", "slink");
+        at.relative_symlink_file("slink", "slink2");
+        ucmd.args(&["--link", "-L", from, "z"]).succeeds();
+        assert!(at.file_exists("z") && !at.symlink_exists("z"));
+        assert_eq!(at.read("z"), "f");
+        // checking that it's the same hard link
+        at.append("z", "g");
+        assert_eq!(at.read("file"), "fg");
+    }
+}
+
+// Android doesn't allow creating hard links
+#[cfg(not(target_os = "android"))]
+#[test]
+fn test_cp_mode_hardlink_no_dereference() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.touch("file");
+    at.write("file", "f");
+    at.relative_symlink_file("file", "slink");
+    at.relative_symlink_file("slink", "slink2");
+    ucmd.args(&["--link", "-P", "slink2", "z"]).succeeds();
+    assert!(at.symlink_exists("z"));
+    assert_eq!(at.read_symlink("z"), "slink");
+}
+
+#[test]
+fn test_remove_destination_symbolic_link_loop() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.symlink_file("loop", "loop");
+    at.plus("loop");
+    at.touch("f");
+    ucmd.args(&["--remove-destination", "f", "loop"])
+        .succeeds()
+        .no_stdout()
+        .no_stderr();
+    assert!(at.file_exists("loop"));
+}
+
+/// Test that copying a directory to itself is disallowed.
+#[test]
+fn test_copy_directory_to_itself_disallowed() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.mkdir("d");
+    #[cfg(not(windows))]
+    let expected = "cp: cannot copy a directory, 'd', into itself, 'd/d'";
+    #[cfg(windows)]
+    let expected = "cp: cannot copy a directory, 'd', into itself, 'd\\d'";
+    ucmd.args(&["-R", "d", "d"]).fails().stderr_only(expected);
+}
+
+/// Test that copying a nested directory to itself is disallowed.
+#[test]
+fn test_copy_nested_directory_to_itself_disallowed() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.mkdir("a");
+    at.mkdir("a/b");
+    at.mkdir("a/b/c");
+    #[cfg(not(windows))]
+    let expected = "cp: cannot copy a directory, 'a/b', into itself, 'a/b/c/b'";
+    #[cfg(windows)]
+    let expected = "cp: cannot copy a directory, 'a/b', into itself, 'a/b/c\\b'";
+    ucmd.args(&["-R", "a/b", "a/b/c"])
+        .fails()
+        .stderr_only(expected);
+}
+
+/// Test for preserving permissions when copying a directory.
+#[cfg(not(windows))]
+#[test]
+fn test_copy_dir_preserve_permissions() {
+    // Create a directory that has some non-default permissions.
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.mkdir("d1");
+    at.set_mode("d1", 0o0500);
+
+    // Copy the directory, preserving those permissions.
+    //
+    //         preserve permissions (mode, ownership, timestamps)
+    //            |    copy directories recursively
+    //            |      |   from this source directory
+    //            |      |    |   to this destination
+    //            |      |    |     |
+    //            V      V    V     V
+    ucmd.args(&["-p", "-R", "d1", "d2"])
+        .succeeds()
+        .no_stderr()
+        .no_stdout();
+    assert!(at.dir_exists("d2"));
+
+    // Assert that the permissions are preserved.
+    let metadata1 = at.metadata("d1");
+    let metadata2 = at.metadata("d2");
+    assert_metadata_eq!(metadata1, metadata2);
+}
+
+/// Test for preserving permissions when copying a directory, even in
+/// the face of an inaccessible file in that directory.
+#[cfg(not(windows))]
+#[test]
+fn test_copy_dir_preserve_permissions_inaccessible_file() {
+    // Create a directory that has some non-default permissions and
+    // contains an inaccessible file.
+    let (at, mut ucmd) = at_and_ucmd!();
+    at.mkdir("d1");
+    at.touch("d1/f");
+    at.set_mode("d1/f", 0);
+    at.set_mode("d1", 0o0500);
+
+    // Copy the directory, preserving those permissions. There should
+    // be an error message that the file `d1/f` is inaccessible.
+    //
+    //         preserve permissions (mode, ownership, timestamps)
+    //            |    copy directories recursively
+    //            |      |   from this source directory
+    //            |      |    |   to this destination
+    //            |      |    |     |
+    //            V      V    V     V
+    ucmd.args(&["-p", "-R", "d1", "d2"])
+        .fails()
+        .status_code(1)
+        .stderr_only("cp: cannot open 'd1/f' for reading: Permission denied");
+    assert!(at.dir_exists("d2"));
+    assert!(!at.file_exists("d2/f"));
+
+    // Assert that the permissions are preserved.
+    let metadata1 = at.metadata("d1");
+    let metadata2 = at.metadata("d2");
+    assert_metadata_eq!(metadata1, metadata2);
+}
