@@ -39,6 +39,11 @@ static COMPLEX_SEQUENCE: &TestedSequence = &TestedSequence {
     sequence: "9-,6-7,-2,4",
 };
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_byte_sequence() {
     for param in ["-b", "--bytes", "--byt"] {
