@@ -5,6 +5,11 @@ use std::env;
 use std::path::Path;
 use tempfile::tempdir;
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(125);
+}
+
 #[test]
 fn test_env_help() {
     new_ucmd!()
@@ -83,7 +88,7 @@ fn test_unset_invalid_variables() {
 
     // Cannot test input with \0 in it, since output will also contain \0. rlimit::prlimit fails
     // with this error: Error { kind: InvalidInput, message: "nul byte found in provided data" }
-    for var in &["", "a=b"] {
+    for var in ["", "a=b"] {
         new_ucmd!().arg("-u").arg(var).run().stderr_only(format!(
             "env: cannot unset {}: Invalid argument",
             var.quote()
