@@ -116,3 +116,8 @@ fn test_check_sha1() {
         .stdout_is("testf: OK\n")
         .stderr_is("");
 }
+
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
