@@ -9,6 +9,11 @@ use std::process::Command;
 #[cfg(any(target_os = "linux", target_os = "android"))]
 use std::thread::sleep;
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_install_basic() {
     let (at, mut ucmd) = at_and_ucmd!();
@@ -996,7 +1001,7 @@ fn test_install_backup_numbered_if_existing_backup_existing() {
     assert!(at.file_exists(file_a));
     assert!(at.file_exists(file_b));
     assert!(at.file_exists(file_b_backup));
-    assert!(at.file_exists(&*format!("{}.~2~", file_b)));
+    assert!(at.file_exists(&format!("{}.~2~", file_b)));
 }
 
 #[test]
@@ -1022,7 +1027,7 @@ fn test_install_backup_numbered_if_existing_backup_nil() {
     assert!(at.file_exists(file_a));
     assert!(at.file_exists(file_b));
     assert!(at.file_exists(file_b_backup));
-    assert!(at.file_exists(&*format!("{}.~2~", file_b)));
+    assert!(at.file_exists(&format!("{}.~2~", file_b)));
 }
 
 #[test]
