@@ -4,6 +4,11 @@ extern crate time;
 use self::filetime::*;
 use crate::common::util::*;
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_mv_rename_dir() {
     let (at, mut ucmd) = at_and_ucmd!();
@@ -475,7 +480,7 @@ fn test_mv_numbered_if_existing_backup_existing() {
 
     assert!(at.file_exists(file_b));
     assert!(at.file_exists(file_b_backup));
-    assert!(at.file_exists(&*format!("{}.~2~", file_b)));
+    assert!(at.file_exists(&format!("{}.~2~", file_b)));
 }
 
 #[test]
@@ -496,7 +501,7 @@ fn test_mv_numbered_if_existing_backup_nil() {
 
     assert!(at.file_exists(file_b));
     assert!(at.file_exists(file_b_backup));
-    assert!(at.file_exists(&*format!("{}.~2~", file_b)));
+    assert!(at.file_exists(&format!("{}.~2~", file_b)));
 }
 
 #[test]
