@@ -2,6 +2,11 @@
 
 use crate::common::util::*;
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_should_not_round_floats() {
     new_ucmd!()
