@@ -24,6 +24,11 @@ static ALPHA_OUT: &str = "
 // XXX We could do a better job of ensuring that we have a fresh temp dir to ourselves,
 // not a general one full of other process leftovers.
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 // Test that od can read one file and dump with default format
 #[test]
 fn test_file() {
@@ -70,12 +75,12 @@ fn test_2files() {
     let file1 = tmpdir.join("test1");
     let file2 = tmpdir.join("test2");
 
-    for &(n, a) in &[(1, "a"), (2, "b")] {
+    for (n, a) in [(1, "a"), (2, "b")] {
         println!("number: {} letter:{}", n, a);
     }
 
     // spell-checker:disable-next-line
-    for &(path, data) in &[(&file1, "abcdefghijklmnop"), (&file2, "qrstuvwxyz\n")] {
+    for (path, data) in [(&file1, "abcdefghijklmnop"), (&file2, "qrstuvwxyz\n")] {
         let mut f = File::create(&path).unwrap();
         assert!(
             f.write_all(data.as_bytes()).is_ok(),
@@ -127,7 +132,7 @@ fn test_from_mixed() {
 
     // spell-checker:disable-next-line
     let (data1, data2, data3) = ("abcdefg", "hijklmnop", "qrstuvwxyz\n");
-    for &(path, data) in &[(&file1, data1), (&file3, data3)] {
+    for (path, data) in [(&file1, data1), (&file3, data3)] {
         let mut f = File::create(&path).unwrap();
         assert!(
             f.write_all(data.as_bytes()).is_ok(),
@@ -827,7 +832,8 @@ fn test_traditional_only_label() {
 
 #[test]
 fn test_od_invalid_bytes() {
-    const INVALID_SIZE: &str = "1fb4t";
+    const INVALID_SIZE: &str = "x";
+    const INVALID_SUFFIX: &str = "1fb4t";
     const BIG_SIZE: &str = "1Y";
 
     // NOTE:
@@ -852,6 +858,16 @@ fn test_od_invalid_bytes() {
                 option, INVALID_SIZE
             ));
 
+        new_ucmd!()
+            .arg(format!("{}={}", option, INVALID_SUFFIX))
+            .arg("file")
+            .fails()
+            .code_is(1)
+            .stderr_only(format!(
+                "od: invalid suffix in {} argument '{}'",
+                option, INVALID_SUFFIX
+            ));
+
         #[cfg(not(target_pointer_width = "128"))]
         new_ucmd!()
             .arg(format!("{}={}", option, BIG_SIZE))
