@@ -119,6 +119,11 @@ impl RandomFile {
     }
 }
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_split_default() {
     let (at, mut ucmd) = at_and_ucmd!();
@@ -257,14 +262,12 @@ fn test_filter() {
     // assert all characters are 'i' / no character is not 'i'
     // (assert that command succeeded)
     let glob = Glob::new(&at, ".", r"x[[:alpha:]][[:alpha:]]$");
-    assert!(
-        glob.collate().iter().find(|&&c| {
-            // is not i
-            c != (b'i')
+    assert!(!glob.collate().iter().any(|&c| {
+        // is not i
+        c != (b'i')
             // is not newline
             && c != (b'\n')
-        }) == None
-    );
+    }));
 }
 
 #[test]
@@ -698,3 +701,29 @@ fn test_multiple_of_input_chunk() {
     }
     assert_eq!(glob.collate(), at.read_bytes(name));
 }
+
+#[test]
+fn test_numeric_suffix() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    ucmd.args(&["-n", "4", "--numeric-suffixes", "9", "threebytes.txt"])
+        .succeeds()
+        .no_stdout()
+        .no_stderr();
+    assert_eq!(at.read("x09"), "a");
+    assert_eq!(at.read("x10"), "b");
+    assert_eq!(at.read("x11"), "c");
+    assert_eq!(at.read("x12"), "");
+}
+
+#[test]
+fn test_hex_suffix() {
+    let (at, mut ucmd) = at_and_ucmd!();
+    ucmd.args(&["-n", "4", "--hex-suffixes", "9", "threebytes.txt"])
+        .succeeds()
+        .no_stdout()
+        .no_stderr();
+    assert_eq!(at.read("x09"), "a");
+    assert_eq!(at.read("x0a"), "b");
+    assert_eq!(at.read("x0b"), "c");
+    assert_eq!(at.read("x0c"), "");
+}
