@@ -59,6 +59,11 @@ fn str_to_filetime(format: &str, s: &str) -> FileTime {
     FileTime::from_unix_time(offset_dt.unix_timestamp(), tm.nanosecond())
 }
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_touch_default() {
     let (at, mut ucmd) = at_and_ucmd!();
