@@ -1,5 +1,10 @@
 use crate::common::util::*;
 
+#[test]
+fn test_invalid_arg() {
+    new_ucmd!().arg("--definitely-invalid").fails().code_is(1);
+}
+
 #[test]
 fn test_uname() {
     new_ucmd!().succeeds();
